// RealisticHealth v1.0 shader file

extern float contrast <
	string UIName = "Contrast";
	string UIWidget = "slider";
	float UIMin = 0.0f;
	float UIMax = 4.0f;
	float UIStep = 0.01f;
> = 1;

extern float brightness <
	string UIName = "Brightness";
	string UIWidget = "slider";
	float UIMin = 0.0f;
	float UIMax = 4.0f;
	float UIStep = 0.01f;
> = 1;

extern float saturation <
	string UIName = "Saturation";
	string UIWidget = "slider";
	float UIMin = 0.0f;
	float UIMax = 4.0f;
	float UIStep = 0.01f;
> = 1;

extern float radialcontrast <
	string UIName = "Radial Contrast";
	string UIWidget = "slider";
	float UIMin = -4.0f;
	float UIMax = 4.0f;
	float UIStep = 0.01f;
> = 0;

extern float radialbrightness <
	string UIName = "Radial Brightness";
	string UIWidget = "slider";
	float UIMin = -4.0f;
	float UIMax = 4.0f;
	float UIStep = 0.01f;
> = 0;

extern float radialsaturation <
	string UIName = "Radial Saturation";
	string UIWidget = "slider";
	float UIMin = -4.0f;
	float UIMax = 4.0f;
	float UIStep = 0.01f;
> = 0;

texture thisframe;	// the current frame from before any effects are applied from this file

sampler currentFrameSampler = sampler_state
{
	texture = <thisframe>;
	AddressU = CLAMP;
	AddressV = CLAMP;
	MINFILTER = POINT;
	MAGFILTER = POINT;
};

struct VSOUT
{
	float4 vertPos : POSITION;
	float2 UVCoord : TEXCOORD0;
};

struct VSIN
{
	float4 vertPos : POSITION0;
	float2 UVCoord : TEXCOORD0;
};

VSOUT FrameVS(VSIN IN)
{
	VSOUT OUT = (VSOUT)0.0f;	// initialize to zero, avoid complaints.
	OUT.vertPos = IN.vertPos;
	OUT.UVCoord = IN.UVCoord;
	return OUT;
};

typedef half3 color3;
typedef half4 color4;

// Effect Functions
color3 doContrast (color3 color, float amt)
{
	return (color - 0.5) * amt + 0.5;
}

color3 doBrightness (color3 color, float amt)
{
	return color * max(0.0, amt);
}

color3 doSaturation (color3 color, float amt)
{
	float luminance = dot(color3(0.299, 0.587, 0.114), color);
	return lerp(luminance, color, amt);
}

float getRadius(float2 UVcoord)
{
	return 2.0 * distance(float2(0.5, 0.5), UVcoord);
}

// Main
color4 ApplyShaderEffects(float2 uv : TEXCOORD0) : COLOR0
{
	color4 color = tex2D(currentFrameSampler, uv);
	float radius = getRadius(uv);

	color.rgb = doContrast(color.rgb, contrast + radius * radialcontrast);
	color.rgb = doBrightness(color.rgb, brightness + radius * radialbrightness);
	color.rgb = doSaturation(color.rgb, saturation + radius * radialsaturation);
	return color;
}

technique t0
{
	pass p0
	{
		//VertexShader = compile vs_1_1 FrameVS();	// unneeded unless the compile target is PS3.0
		PixelShader = compile ps_2_0 ApplyShaderEffects();
		CullMode = none;
		ZEnable = false;
		ZWriteEnable = false;
		AlphaBlendEnable = false;
	}
}
